@@ -4,6 +4,6 @@
     To be documented
 """
 
-__version__ = "0.2.8"
+__version__ = "0.3.0"
 
-from overlay import *
\ No newline at end of file
+from . import overlay
